==> mythplugins-0.19.tar.bz2: mythplugins-0.19/mythgame/i18n/mythgame_es.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GameTree</name>
    <message>
        <source>All Games</source>
        <translation>Todos los Juegos</translation>
    </message>
    <message>
        <source>Favourites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>-   By Name</source>
        <translation>- Por Nombre</translation>
    </message>
    <message>
        <source>-   By Year</source>
        <translation>- Por Año</translation>
    </message>
    <message>
        <source>-   By Genre</source>
        <translation>- Por Género</translation>
    </message>
    <message>
        <source>Players Available. 

 Please pick one.</source>
        <translation>Reproductores disponibles.  

Por favor elija uno.</translation>
    </message>
</context>
<context>
    <name>MythGamePlayerEditor</name>
    <message>
        <source>Game Player Menu</source>
        <translation>Menú Jugador</translation>
    </message>
    <message>
        <source>Edit..</source>
        <translation>Editar..</translation>
    </message>
    <message>
        <source>Delete..</source>
        <translation>Borrar..</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this item?</source>
        <translation>¿Seguro de borrar este elemento?</translation>
    </message>
    <message>
        <source>Yes, delete It</source>
        <translation>Sí, bórralo</translation>
    </message>
    <message>
        <source>No, don&apos;t</source>
        <translation>No, no lo hagas</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Game display order</source>
        <translation>Órden juegos</translation>
    </message>
    <message>
        <source>MythGame Settings -- General</source>
        <translation>Ajustes MythGame -- General</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Order in which to sort the games - this is for all systems. Available choices: system, year, genre and gamename</source>
        <translation>Órden en que mostrar los juegos - para todos los sistemas. Opciones posibles: sistema, año, género y nombre</translation>
    </message>
    <message>
        <source>Favourite display order</source>
        <translation>Órden favoritos</translation>
    </message>
    <message>
        <source>Order in which to sort the games marked as favourites - this is for all systems. Available choices: system, year, genre and gamename</source>
        <translation>Órden en que mostrar los juegos marcados como favoritos - para todos los sistemas. Opciones posibles: sistema, año, género y nombre</translation>
    </message>
    <message>
        <source>Indepth Game Scan</source>
        <translation>Exploración profunda Juegos</translation>
    </message>
    <message>
        <source>Enabling this causes a game scan to gather crc values and attempt to find out more detailed information about the game: NOTE this can greatly increase the time a gamescan takes based on the amount of games scanned.</source>
        <translation>Activar esto causa que la exploración compruebe valores crc para buscar información más detallada sobre el juego: NOTA, esto puede incrementar mucho el tiempo de exploración, basado en el número de juegos.</translation>
    </message>
    <message>
        <source>Prompt for removal of deleted rom(s)</source>
        <translation>Preguntar por borrado de rom(s)</translation>
    </message>
    <message>
        <source>This enables a prompt for removing deleted roms from the database during a  gamescan</source>
        <translation>Esto activa la pregunta de borrar roms de la base de datos durante una exploración</translation>
    </message>
    <message>
        <source>Display Files Names in Game Tree</source>
        <translation>Mostrar nombres de fichero en el Árbol de Juegos</translation>
    </message>
    <message>
        <source>Enabling this causes the filenames to be displayed in the game tree rather than the trimmed/looked up gamename</source>
        <translation>Activar esto causa que los nombres de fichero se muestren en el árbol de juegos en vez del nombre del juego</translation>
    </message>
    <message>
        <source>Allow games to span multiple roms/disks</source>
        <translation>Permitir que los juegos sean múltiples discos/roms</translation>
    </message>
    <message>
        <source>This setting means that we will look for items like game.1.rom, game.2.rom and consider them a single game.</source>
        <translation>Este ajuste significa que buscaremos elementos como game.1.rom, game.2.rom y considerarlos un sólo juego.</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Path+name of binary and optional parameters. %s can be used to represent the name of any rom being launched. if not specified the rom filename will be added to the end of the command. As well %d1, %d2, %d3 and %d4 represent disks in a multidisk/game situation</source>
        <translation>Ruta+nombre del binario y parámetros opcionales. %s puede ser usado para representar el nombre del rom lanzado. Si no se especifica el nombre de la rom será añadido al final del comando. También %d1, %d2, %d3 y %d4 representan discos en un juego multidisco</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Type of Game/Emulator. Mostly for informational purposes and has little effect on the function of your system.</source>
        <translation>Tipo de Emulador/Juego. Para propósitos informacionales, no tiene apenas efecto en el funcionamiento.</translation>
    </message>
    <message>
        <source>Rom Path</source>
        <translation>Ruta a Roms</translation>
    </message>
    <message>
        <source>Location of the ROM files for this emulator</source>
        <translation>Lugar de los ficheros ROM para este emulador</translation>
    </message>
    <message>
        <source>Working Directory</source>
        <translation>Directorio de Trabajo</translation>
    </message>
    <message>
        <source>Directory to change to before launching emulator. Blank is usually fine</source>
        <translation>Directorio a cambiar antes de lanzar emulador. Vacío suele estar bien</translation>
    </message>
    <message>
        <source>File Extensions</source>
        <translation>Extensiones Fichero</translation>
    </message>
    <message>
        <source>List of all file extensions to be used for this emulator. Blank means any file under ROM PATH is considered to be used with this emulator</source>
        <translation>Lista de todas las extensiones de fichero usadas por este emulador. Vacío significa que cualquier fichero bajo RUTA ROM será considerado para usar con este emulador</translation>
    </message>
    <message>
        <source>ScreenShots</source>
        <translation>Capturas</translation>
    </message>
    <message>
        <source>Path to any screenshots for this player</source>
        <translation>Ruta a alguna captura de este juego</translation>
    </message>
    <message>
        <source>Game Player Setup</source>
        <translation>Ajustes Reproductor</translation>
    </message>
    <message>
        <source>(New Game Player)</source>
        <translation>(Nuevo Reproductor Juegos)</translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation>OTRO</translation>
    </message>
    <message>
        <source>MAME</source>
        <translation></translation>
    </message>
    <message>
        <source>NES</source>
        <translation></translation>
    </message>
    <message>
        <source>SNES</source>
        <translation></translation>
    </message>
    <message>
        <source>N64</source>
        <translation></translation>
    </message>
    <message>
        <source>PCE/TG16</source>
        <translation></translation>
    </message>
    <message>
        <source>GENESIS/MEGADRIVE</source>
        <translation></translation>
    </message>
    <message>
        <source>PC GAME</source>
        <translation>JUEGO PC</translation>
    </message>
    <message>
        <source>AMIGA</source>
        <translation></translation>
    </message>
    <message>
        <source>ATARI</source>
        <translation></translation>
    </message>
    <message>
        <source>Player Name</source>
        <translation>Nombre Reproductor</translation>
    </message>
    <message>
        <source>Name of this Game and or Emulator</source>
        <translation>Nombre de este Juego y/o Emulador</translation>
    </message>
    <message>
        <source>19xx</source>
        <translation></translation>
    </message>
    <message>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <source>No</source>
        <translation></translation>
    </message>
    <message>
        <source>No to all</source>
        <translation>No a todo</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>Yes to all</source>
        <translation>Sí a todo</translation>
    </message>
    <message>
        <source>File Missing</source>
        <translation>Fichero desaparecido</translation>
    </message>
    <message>
        <source>%1 appears to be missing.
Remove it from the database?</source>
        <translation>%1 parece que no existe.
¿Borrarlo de la base de datos?</translation>
    </message>
    <message>
        <source>Are you sure?</source>
        <translation>¿Seguro?</translation>
    </message>
    <message>
        <source>This will clear all Game Meta Data
from the database. Are you sure you
want to do this?</source>
        <translation>Esto borrará todos los metadatos de los juegos
de la base de datos. ¿Seguro que
quiere hacerlo?</translation>
    </message>
    <message>
        <source>SEGA/MASTER SYSYTEM</source>
        <translation>SEGA/MASTER SYSTEM</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>System:</source>
        <translation>Sistema:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>Año:</translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation>Género:</translation>
    </message>
    <message>
        <source>Favorite:</source>
        <translation>Favorito:</translation>
    </message>
</context>
</TS>

==> mythplugins-0.23.tar.bz2: mythplugins-0.23/mythgame/i18n/mythgame_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>GameUI</name>
    <message>
        <source>All Games</source>
        <translation type="unfinished">Todos los Juegos</translation>
    </message>
    <message>
        <source>-   By Genre</source>
        <translation type="unfinished">- Por Género</translation>
    </message>
    <message>
        <source>-   By Year</source>
        <translation type="unfinished">- Por Año</translation>
    </message>
    <message>
        <source>-   By Name</source>
        <translation type="unfinished">- Por Nombre</translation>
    </message>
    <message>
        <source>-   By Publisher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose System for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MythControls</name>
    <message>
        <source>Game frontend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle the current game as a favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show incremental search dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incremental search find next match</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MythGamePlayerEditor</name>
    <message>
        <source>Game Player Menu</source>
        <translation>Menú Jugador</translation>
    </message>
    <message>
        <source>Edit..</source>
        <translation>Editar..</translation>
    </message>
    <message>
        <source>Delete..</source>
        <translation>Borrar..</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this item?</source>
        <translation>¿Seguro de borrar este elemento?</translation>
    </message>
    <message>
        <source>Yes, delete It</source>
        <translation>Sí, bórralo</translation>
    </message>
    <message>
        <source>No, don&apos;t</source>
        <translation>No, no lo hagas</translation>
    </message>
    <message>
        <source>Game Players</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Game display order</source>
        <translation>Órden juegos</translation>
    </message>
    <message>
        <source>MythGame Settings -- General</source>
        <translation>Ajustes MythGame -- General</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Order in which to sort the games - this is for all systems. Available choices: system, year, genre and gamename</source>
        <translation>Órden en que mostrar los juegos - para todos los sistemas. Opciones posibles: sistema, año, género y nombre</translation>
    </message>
    <message>
        <source>Favourite display order</source>
        <translation>Órden favoritos</translation>
    </message>
    <message>
        <source>Order in which to sort the games marked as favourites - this is for all systems. Available choices: system, year, genre and gamename</source>
        <translation>Órden en que mostrar los juegos marcados como favoritos - para todos los sistemas. Opciones posibles: sistema, año, género y nombre</translation>
    </message>
    <message>
        <source>Indepth Game Scan</source>
        <translation>Exploración profunda Juegos</translation>
    </message>
    <message>
        <source>Enabling this causes a game scan to gather crc values and attempt to find out more detailed information about the game: NOTE this can greatly increase the time a gamescan takes based on the amount of games scanned.</source>
        <translation>Activar esto causa que la exploración compruebe valores crc para buscar información más detallada sobre el juego: NOTA, esto puede incrementar mucho el tiempo de exploración, basado en el número de juegos.</translation>
    </message>
    <message>
        <source>Prompt for removal of deleted rom(s)</source>
        <translation>Preguntar por borrado de rom(s)</translation>
    </message>
    <message>
        <source>This enables a prompt for removing deleted roms from the database during a  gamescan</source>
        <translation>Esto activa la pregunta de borrar roms de la base de datos durante una exploración</translation>
    </message>
    <message>
        <source>Display Files Names in Game Tree</source>
        <translation>Mostrar nombres de fichero en el Árbol de Juegos</translation>
    </message>
    <message>
        <source>Enabling this causes the filenames to be displayed in the game tree rather than the trimmed/looked up gamename</source>
        <translation>Activar esto causa que los nombres de fichero se muestren en el árbol de juegos en vez del nombre del juego</translation>
    </message>
    <message>
        <source>Allow games to span multiple roms/disks</source>
        <translation>Permitir que los juegos sean múltiples discos/roms</translation>
    </message>
    <message>
        <source>This setting means that we will look for items like game.1.rom, game.2.rom and consider them a single game.</source>
        <translation>Este ajuste significa que buscaremos elementos como game.1.rom, game.2.rom y considerarlos un sólo juego.</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Type of Game/Emulator. Mostly for informational purposes and has little effect on the function of your system.</source>
        <translation>Tipo de Emulador/Juego. Para propósitos informacionales, no tiene apenas efecto en el funcionamiento.</translation>
    </message>
    <message>
        <source>Rom Path</source>
        <translation>Ruta a Roms</translation>
    </message>
    <message>
        <source>Location of the ROM files for this emulator</source>
        <translation>Lugar de los ficheros ROM para este emulador</translation>
    </message>
    <message>
        <source>Working Directory</source>
        <translation>Directorio de Trabajo</translation>
    </message>
    <message>
        <source>Directory to change to before launching emulator. Blank is usually fine</source>
        <translation>Directorio a cambiar antes de lanzar emulador. Vacío suele estar bien</translation>
    </message>
    <message>
        <source>File Extensions</source>
        <translation>Extensiones Fichero</translation>
    </message>
    <message>
        <source>Game Player Setup</source>
        <translation>Ajustes Reproductor</translation>
    </message>
    <message>
        <source>(New Game Player)</source>
        <translation>(Nuevo Reproductor Juegos)</translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation>OTRO</translation>
    </message>
    <message>
        <source>MAME</source>
        <translation></translation>
    </message>
    <message>
        <source>NES</source>
        <translation></translation>
    </message>
    <message>
        <source>SNES</source>
        <translation></translation>
    </message>
    <message>
        <source>N64</source>
        <translation></translation>
    </message>
    <message>
        <source>PCE/TG16</source>
        <translation></translation>
    </message>
    <message>
        <source>GENESIS/MEGADRIVE</source>
        <translation></translation>
    </message>
    <message>
        <source>PC GAME</source>
        <translation>JUEGO PC</translation>
    </message>
    <message>
        <source>AMIGA</source>
        <translation></translation>
    </message>
    <message>
        <source>ATARI</source>
        <translation></translation>
    </message>
    <message>
        <source>Player Name</source>
        <translation>Nombre Reproductor</translation>
    </message>
    <message>
        <source>Name of this Game and or Emulator</source>
        <translation>Nombre de este Juego y/o Emulador</translation>
    </message>
    <message>
        <source>19xx</source>
        <translation></translation>
    </message>
    <message>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <source>No</source>
        <translation></translation>
    </message>
    <message>
        <source>No to all</source>
        <translation>No a todo</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>Yes to all</source>
        <translation>Sí a todo</translation>
    </message>
    <message>
        <source>File Missing</source>
        <translation>Fichero desaparecido</translation>
    </message>
    <message>
        <source>%1 appears to be missing.
Remove it from the database?</source>
        <translation>%1 parece que no existe.
¿Borrarlo de la base de datos?</translation>
    </message>
    <message>
        <source>Are you sure?</source>
        <translation>¿Seguro?</translation>
    </message>
    <message>
        <source>This will clear all Game Meta Data
from the database. Are you sure you
want to do this?</source>
        <translation>Esto borrará todos los metadatos de los juegos
de la base de datos. ¿Seguro que
quiere hacerlo?</translation>
    </message>
    <message>
        <source>SEGA/MASTER SYSYTEM</source>
        <translation></translation>
    </message>
    <message>
        <source>A Comma seperated list of all file extensions for this emulator. Blank means any file under ROM PATH is considered to be used with this emulator</source>
        <translation>Lista de todas las extensiones separadas por coma usadas por este emulador. Vacío significa que cualquier fichero bajo RUTA ROM será considerado para usar con este emulador</translation>
    </message>
    <message>
        <source>GAMEGEAR</source>
        <translation></translation>
    </message>
    <message>
        <source>Updating %1(%2) ROM database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verifying %1 files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scanning for %1 game(s)...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hash filenames in display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable hashing of names in the display tree. This can make navigating long lists a little faster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Binary and optional parameters. Multiple commands seperated with &apos;;&apos; . Use %s for the rom name. %d1, %d2, %d3 and %d4 represent disks in a multidisk/game. %s auto appended if not specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory where Game Screenshots are stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory will be the default browse location when assigning screenshots.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory where Game Fanart is stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory will be the default browse location when assigning fanart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory where Game Boxart is stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory will be the default browse location when assigning boxart.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>System:</source>
        <translation>Sistema:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>Año:</translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation>Género:</translation>
    </message>
    <message>
        <source>Favorite:</source>
        <translation>Favorito:</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">Sí</translation>
    </message>
    <message>
        <source>Edit Game Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Country:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Publisher:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plot:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshot:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fanart:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boxart:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>/path/to/the/thing.jpg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rompath:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System(s):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CRC:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Plot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Players</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan for Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Game Data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
